vexmpp package
==============

Subpackages
-----------

.. toctree::

    vexmpp.features
    vexmpp.protocols
    vexmpp.suelta
    vexmpp.vex

Submodules
----------

vexmpp\.client module
---------------------

.. automodule:: vexmpp.client
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.errors module
---------------------

.. automodule:: vexmpp.errors
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.jid module
------------------

.. automodule:: vexmpp.jid
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.metrics module
----------------------

.. automodule:: vexmpp.metrics
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.namespaces module
-------------------------

.. automodule:: vexmpp.namespaces
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.parser module
---------------------

.. automodule:: vexmpp.parser
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.ssl\_transport module
-----------------------------

.. automodule:: vexmpp.ssl_transport
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.stanzas module
----------------------

.. automodule:: vexmpp.stanzas
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.stream module
---------------------

.. automodule:: vexmpp.stream
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.utils module
--------------------

.. automodule:: vexmpp.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vexmpp
    :members:
    :undoc-members:
    :show-inheritance:
